==> mimir-2.10.4.tar.gz: mimir-mimir-2.10.4/MAINTAINERS.md <==
The following are the main/default maintainers:

- Arve Knudsen — [@aknuds1](https://github.com/aknuds1) ([Grafana Labs](https://grafana.com/))
- Bryan Boreham — [@bboreham](https://github.com/bboreham) ([Grafana Labs](https://grafana.com/))
- Dimitar Dimitrov - [@dimitarvdimitrov](https://github.com/dimitarvdimitrov) ([Grafana Labs](https://grafana.com/))
- George Krajcsovits - [@krajorama](https://github.com/krajorama) ([Grafana Labs](https://grafana.com/))
- Johanna Ratliff — [@johannaratliff](https://github.com/johannaratliff) ([Grafana Labs](https://grafana.com/))
- Marco Pracucci — [@pracucci](https://github.com/pracucci) ([Grafana Labs](https://grafana.com/))
- Mauro Stettler — [@replay](https://github.com/replay) ([Grafana Labs](https://grafana.com/))
- Nick Pillitteri — [@56quarters](https://github.com/56quarters) ([Grafana Labs](https://grafana.com/))
- Oleg Zaytsev — [@colega](https://github.com/colega) ([Grafana Labs](https://grafana.com/))
- Peter Štibraný — [@pstibrany](https://github.com/pstibrany) ([Grafana Labs](https://grafana.com/))
- Tyler Reid — [@treid314](https://github.com/treid314) ([Grafana Labs](https://grafana.com/))
- Patrick Oyarzun — [@Logiraptor](https://github.com/Logiraptor) ([Grafana Labs](https://grafana.com/))
- Charles Korn — [@charleskorn](https://github.com/charleskorn) ([Grafana Labs](https://grafana.com/))

Some parts of the codebase have other maintainers, the package paths also include all sub-packages:

- `docs`:
  - Jack Baldry - [@jdbaldry](https://github.com/jdbaldry) ([Grafana Labs](https://grafana.com/))
  - Ursula Kallio — [@osg-grafana](https://github.com/osg-grafana) ([Grafana Labs](https://grafana.com/))
- `pkg/alertmanager`:
  - Josh Abreu Mesa — [@gotjosh](https://github.com/gotjosh) ([Grafana Labs](https://grafana.com/))
  - Steve Simpson - [@stevesg](https://github.com/stevesg) ([Grafana Labs](https://grafana.com/))
- `pkg/frontend`:
  - Cyril Tovena — [@cyriltovena](https://github.com/cyriltovena) ([Grafana Labs](https://grafana.com/)) # limited to reviews
- `pkg/ruler`:
  - Josh Abreu Mesa — [@gotjosh](https://github.com/gotjosh) ([Grafana Labs](https://grafana.com/))
  - Steve Simpson - [@stevesg](https://github.com/stevesg) ([Grafana Labs](https://grafana.com/))
- `packaging`:
  - Wilfried ROSET - [@wilfriedroset](https://github.com/wilfriedroset) ([OVHcloud](https://www.ovhcloud.com/))
  - Nicolas DUPEUX - [@vaxvms](https://github.com/vaxvms) ([OVHcloud](https://www.ovhcloud.com/))
  - Julien GIRARD - [@bubu11e](https://github.com/bubu11e) ([OVHcloud](https://www.ovhcloud.com/))

==> mimir-2.13.0.tar.gz: mimir-mimir-2.13.0/MAINTAINERS.md <==
The following are the main/default maintainers:

- Andy Asp [@andyasp](https://github.com/andyasp) ([Grafana Labs](https://grafana.com/))
- Arve Knudsen — [@aknuds1](https://github.com/aknuds1) ([Grafana Labs](https://grafana.com/))
- Bryan Boreham — [@bboreham](https://github.com/bboreham) ([Grafana Labs](https://grafana.com/))
- Casie Chen — [@chencs](https://github.com/chencs) ([Grafana Labs](https://grafana.com/))
- Charles Korn — [@charleskorn](https://github.com/charleskorn) ([Grafana Labs](https://grafana.com/))
- Dimitar Dimitrov - [@dimitarvdimitrov](https://github.com/dimitarvdimitrov) ([Grafana Labs](https://grafana.com/))
- Fayzal Ghantiwala [@fayzal-g](https://github.com/fayzal) ([Grafana Labs](https://grafana.com/))
- Felix Beuke [@flxbk](https://github.com/flxbk) ([Grafana Labs](https://grafana.com/))
- Franco Posa [@francoposa](https://github.com/francoposa) ([Grafana Labs](https://grafana.com/))
- George Krajcsovits - [@krajorama](https://github.com/krajorama) ([Grafana Labs](https://grafana.com/))
- Jeanette Tan [@zenador](https://github.com/zenador) ([Grafana Labs](https://grafana.com/))
- Johanna Ratliff — [@johannaratliff](https://github.com/johannaratliff) ([Grafana Labs](https://grafana.com/))
- Jon Kartago Lamida [@lamida](https://github.com/lamida) ([Grafana Labs](https://grafana.com/))
- Jonathan Halterman [@jhalterman](https://github.com/jhalterman) ([Grafana Labs](https://grafana.com/))
- Joshua Hesketh [@jhesketh](https://github.com/jhesketh) ([Grafana Labs](https://grafana.com/))
- Justin Lei [@leizor](https://github.com/leizor) ([Grafana Labs](https://grafana.com/))
- Marco Pracucci — [@pracucci](https://github.com/pracucci) ([Grafana Labs](https://grafana.com/))
- Mauro Stettler — [@replay](https://github.com/replay) ([Grafana Labs](https://grafana.com/))
- Miguel Ángel Ortuño [@ortuman](https://github.com/ortuman) ([Grafana Labs](https://grafana.com/))
- Nick Pillitteri — [@56quarters](https://github.com/56quarters) ([Grafana Labs](https://grafana.com/))
- Oleg Zaytsev — [@colega](https://github.com/colega) ([Grafana Labs](https://grafana.com/))
- Patrick Oyarzun — [@Logiraptor](https://github.com/Logiraptor) ([Grafana Labs](https://grafana.com/))
- Patryk Prus [@pr00se](https://github.com/pr00se) ([Grafana Labs](https://grafana.com/))
- Peter Štibraný — [@pstibrany](https://github.com/pstibrany) ([Grafana Labs](https://grafana.com/))
- Tyler Reid — [@treid314](https://github.com/treid314) ([Grafana Labs](https://grafana.com/))
- Vernon Miller [@aldernero](https://github.com/aldernero) ([Grafana Labs](https://grafana.com/))
- Ying-jeanne Wang [@ying-jeanne](https://github.com/ying-jeanne) ([Grafana Labs](https://grafana.com/))
- Đurica Yuri Nikolić [@duricanikolic](https://github.com/duricanikolic) ([Grafana Labs](https://grafana.com/))

Some parts of the codebase have other maintainers, the package paths also include all sub-packages:

- `docs`:
  - Jack Baldry - [@jdbaldry](https://github.com/jdbaldry) ([Grafana Labs](https://grafana.com/))
- `pkg/alertmanager`:
  - Josh Abreu Mesa — [@gotjosh](https://github.com/gotjosh) ([Grafana Labs](https://grafana.com/))
  - Steve Simpson - [@stevesg](https://github.com/stevesg) ([Grafana Labs](https://grafana.com/))
- `pkg/frontend`:
  - Cyril Tovena — [@cyriltovena](https://github.com/cyriltovena) ([Grafana Labs](https://grafana.com/)) # limited to reviews
- `pkg/ruler`:
  - Josh Abreu Mesa — [@gotjosh](https://github.com/gotjosh) ([Grafana Labs](https://grafana.com/))
  - Steve Simpson - [@stevesg](https://github.com/stevesg) ([Grafana Labs](https://grafana.com/))
- `packaging`:
  - Wilfried ROSET - [@wilfriedroset](https://github.com/wilfriedroset) ([OVHcloud](https://www.ovhcloud.com/))
  - Nicolas DUPEUX - [@vaxvms](https://github.com/vaxvms) ([OVHcloud](https://www.ovhcloud.com/))
  - Julien GIRARD - [@bubu11e](https://github.com/bubu11e) ([OVHcloud](https://www.ovhcloud.com/))
